#=============================================================================
# Doloforge::Service::Ftp : add a ProFTPd server for any configured project
#
# Generate config files from templates, add a config file to the whole,
# reload ProFTPd (well, not yet)
#
# Full help :
#   perldoc Doloforge::Service::Ftp
#=============================================================================


package Doloforge::Service::Ftp;

use strict;

# This base class implements the constructor and help methods in a generic way.
use base qw(Doloforge::Service);


#=============================================================================
=head1 NAME

Doloforge::Service::Ftp : Add a ProFTPd server for any configured project

=head1 SYNOPSIS

    # Update the full configuration, running each client/project/service update
    doloforge config --update

=head1 DESCRIPTION

Todo

=cut


#=============================================================================
# Method update
#
# Update the service configuration on the host, depending on
# client/project/service config files...
# This method receives :
#   option: context options passesd on the command-line (quite useless there)
#   client_conf: client configuration file contents (client.$name.yaml)
#   project_conf: project configuration file contents (project.$name.client.$name.yaml)
# TODO : add FTP users to the /etc/doloforge/ftpd.passwd file, and use that file for FTP authentication

sub update {
    my $self = shift;

    my ($option, $client_conf, $project_conf) = @_;

    # Copy the service skeleton directory into the project local and shared directory.
    foreach my $dirid qw(shared local) {
        $self->skel_copy(
            "$self->{global}->{dir}->{skel}/service/$dirid/$self->{name}",                  # Skeleton directory to copy (skel/service/[local|shared]/[service]/)
            "$self->{global}->{dir}->{$dirid}/$client_conf->{name}/$project_conf->{name}",  # Where to copy it
            $self->{config}->{developerdirs},                                               # reference to the developers directories, that will have to be chown'ed to the following ownership
            $client_conf->{name}, $client_conf->{name},                                     # user/group id of the client who owns this project. Developers of the same group will have write-access to files there.
        ) if ((($dirid eq 'shared') and $self->has_role('nfs_role'))                        # only create shared storage on the NFS server
           or (($dirid eq 'local') and $self->has_role('appserv_role')));                   # only create local storage on application servers
    }
}



1;
__END__

=head1 AUTHOR

Nicolas Huillard <F<nicolas@huillard.net>>, Dolomède

=head1 SEE ALSO

doloforge(1)

=cut
